"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const utils_1 = require("./helpers/utils");
const exists_1 = tslib_1.__importDefault(require("../exists"));
const resolve_package_1 = tslib_1.__importDefault(require("../resolve-package"));
jest.mock('../exists.ts');
jest.mock('../resolve-package.ts');
jest.mock('@cgds/test/package.json', () => ({}), { virtual: true });
const resolveSpy = resolve_package_1.default;
resolveSpy.mockReturnValue('@cgds/test/package.json');
test('should not change css import', () => {
    const source = 'import "@cgds/test/dist/main.css";';
    expect(utils_1.transform(source)).toBe('import "@cgds/test/dist/main.css";');
});
test('should add css import', () => {
    // @ts-ignore
    exists_1.default.mockReturnValueOnce(true);
    const source = 'import Test from "@cgds/test";';
    expect(utils_1.transform(source)).toBe('import Test from "@cgds/test";\nimport "@cgds/test/dist/main.css";');
});
test("shouldn't touch other imports", () => {
    // @ts-ignore
    exists_1.default.mockReturnValueOnce(true);
    const source = 'import Test from "@cgds/test";\nimport NotMe from "@test";';
    expect(utils_1.transform(source)).toBe('import Test from "@cgds/test";\nimport "@cgds/test/dist/main.css";\nimport NotMe from "@test";');
});
test('ensure only one css import is kept', () => {
    const source = 'import Test from "@cgds/test";\nimport "@cgds/test/dist/main.css";import "@cgds/test/dist/main.css";';
    expect(utils_1.transform(source)).toBe('import Test from "@cgds/test";\nimport "@cgds/test/dist/main.css";');
});
test("shouldn't add css import if already present - above", () => {
    const source = 'import "@cgds/test/dist/main.css";\nimport Test from "@cgds/test";';
    expect(utils_1.transform(source)).toBe('import "@cgds/test/dist/main.css";\nimport Test from "@cgds/test";');
});
test("shouldn't add css import if file doesn't exist", () => {
    // @ts-ignore
    exists_1.default.mockReturnValueOnce(false);
    const source = 'import Test from "@cgds/test";';
    expect(utils_1.transform(source)).toBe('import Test from "@cgds/test";');
});
test("should work for other css imports", () => {
    // @ts-ignore
    exists_1.default.mockReturnValueOnce(false);
    const source = 'import "@cgds/some/dist/other.css";';
    expect(utils_1.transform(source)).toBe(source);
});
test("should not fail for deeper imports", () => {
    // @ts-ignore
    exists_1.default.mockReturnValueOnce(false);
    const source = 'import "@cgds/some/dist/other.js";';
    expect(utils_1.transform(source)).toBe(source);
});
//# sourceMappingURL=index.test.js.map