"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const resolve_package_1 = tslib_1.__importDefault(require("./resolve-package"));
const exists_1 = tslib_1.__importDefault(require("./exists"));
/**
 * Find imports of @design-system/cli components and automatically includes their styles.
 */
function includeStyles({ types }, { scope }) {
    const SCOPE_REGEX = new RegExp(`^@${scope}\\/`);
    let cssImports = new Set();
    /** Insert an import for a component */
    function insertCssImports(path, importName) {
        if (!SCOPE_REGEX.test(importName)) {
            return;
        }
        if (importName.match(/\.css$/)) {
            // Only keep 1 import per imported css file
            if (cssImports.has(importName)) {
                path.remove();
            }
            else {
                cssImports.add(importName);
            }
            return;
        }
        const cssImport = `${importName}/dist/main.css`;
        if (exists_1.default(cssImport)) {
            path.insertAfter(types.importDeclaration([], types.stringLiteral(cssImport)));
        }
        // After walk dependencies to find more css to include
        const packageJson = resolve_package_1.default(importName);
        if (!packageJson) {
            return;
        }
        // After walk dependencies to find more css to include
        // eslint-disable-next-line global-require, import/no-dynamic-require, @typescript-eslint/no-var-requires
        const { dependencies = {}, name } = require(packageJson);
        // In case we happen to find a package.json that is for the specified scope
        if (!SCOPE_REGEX.test(name)) {
            return;
        }
        Object.keys(dependencies).forEach((dependency) => insertCssImports(path, dependency));
    }
    return {
        /** Initialization code */
        pre: () => {
            cssImports = new Set();
        },
        visitor: {
            ImportDeclaration(path) {
                const importName = path.node.source.value;
                insertCssImports(path, importName);
            }
        }
    };
}
exports.default = includeStyles;
//# sourceMappingURL=index.js.map